.top-buffer {
  margin-top: 20px;
}

.no-side-padding {
  padding-left: 0;
  padding-right: 0;
}

.pre-wrap-white-space {
  white-space: pre-wrap;
}

.bottom-box {
  vertical-align: bottom !important;
}

.align-with-header{
  bottom: 15px;
  position: relative;
  top: 15px;
}
